@@ -136,9 +136,9 @@ impl Body {
 
     /// Consumes this body object to return a [`Bytes`] that contains all data.
     pub async fn into_bytes(self) -> Result<Bytes, ReadBodyError> {
-        Ok(hyper::body::to_bytes(self.0)
+        hyper::body::to_bytes(self.0)
             .await
-            .map_err(|err| ReadBodyError::Io(IoError::new(ErrorKind::Other, err)))?)
+            .map_err(|err| ReadBodyError::Io(IoError::new(ErrorKind::Other, err)))
     }
 
     /// Consumes this body object to return a [`Vec<u8>`] that contains all
